<?php
/**
 * @file
 *   Plugin include file for export style plugin.
 */

/**
 * Generalized style plugin for export plugins.
 *
 * @ingroup views_style_plugins
 */
class pspp_plugin_style_export_syntax extends pspp_plugin_style_export {
  var $feed_text = 'PSPP Syntax';
  var $feed_file = 'view-%view.sps';

  /**
   * Initialize plugin.
   *
   * Set feed image for shared rendering later.
   */
  function init(&$view, &$display, $options = NULL) {
    parent::init($view, $display, $options = NULL);
    $this->feed_image = drupal_get_path('module', 'pspp') . '/images/pspp-syntax.png';

  }

  /**
   * Set options fields and default values.
   *
   * @return
   * An array of options information.
   */
  function option_definition() {
    $options = parent::option_definition();

    $options['pspp_get_data_type'] = array(
      'default' => 'TXT',
      'translatable' => FALSE,
    );
    $options['pspp_get_data_arrangement'] = array(
      'default' => 'DELIMITED',
      'translatable' => FALSE,
    );
    $options['pspp_get_data_firstcase'] = array(
      'default' => 2,
      'translatable' => FALSE,
    );
    $options['pspp_get_data_importcase'] = array(
      'default' => 'ALL',
      'translatable' => FALSE,
    );
    $options['pspp_get_data_importcase_value'] = array(
      'default' => 0,
      'translatable' => FALSE,
    );
    $options['pspp_get_data_delimiters'] = array(
      'default' => ',',
      'translatable' => FALSE,
    );
    $options['pspp_get_data_qualifier'] = array(
      'default' => '"',
      'translatable' => FALSE,
    );
    $options['pspp_get_data_escape'] = array(
      'default' => FALSE,
      'translatable' => FALSE,
    );
    $options['pspp_get_data_delcase'] = array(
      'default' => 'LINE',
      'translatable' => FALSE,
    );
    $options['pspp_get_data_delcase_value'] = array(
      'default' => 0,
      'translatable' => FALSE,
    );

    return $options;
  }

  function options_form(&$form, &$form_state) {
    parent::options_form($form, $form_state);
    unset($form['parent_sort']);

    $class = 'pspp-get-data-subcmd pspp-get-data-subcmd-';
    $form['pspp_get_data'] = array(
      '#type' => 'fieldset',
      '#title' => t('GET DATA Subcommands'),
      '#collapsible' => TRUE,
      '#collpased' => TRUE,
    );
    $type_options = array(
      'TXT' => 'TXT',
      'GNM' => 'GNM',
      'PSQL' => 'PSQL',
      'ODBC' => 'ODBC (SPSS only)',
      'OLEDB' => 'OLEDB (SPSS only)',
      'XLS' => 'XLS (SPSS only)',
      'XLSX' =>  'XLSX (SPSS only)',
      'XLSM' => 'XLSM (SPSS only)',
    );
    $form['pspp_get_data']['pspp_get_data_type'] = array(
      '#type' => 'select',
      '#title' => t('TYPE Subcommand'),
      '#default_value' => $this->options['pspp_get_data_type'],
      '#options' => $type_options,
    );
    foreach ($type_options as $key => $value) {
      $key_lower = strtolower($key);
      $form['pspp_get_data']['type_'. $key_lower] = array(
        '#type' => 'fieldset',
        '#title' => t('@key specific subcommands', array('@key' => $key)),
        '#collapsible' => TRUE,
        '#collapsed' => TRUE,
        '#prefix' => '<div class="'. $class . $key_lower .'">',
        '#suffix' => '</div>',
      );
    }
    $form['pspp_get_data']['type_txt']['pspp_get_data_arrangement'] = array(
      '#type' => 'select',
      '#title' => t('ARRANGEMENT'),
      '#default_value' => $this->options['pspp_get_data_arrangement'],
      '#options' => drupal_map_assoc(array('DELIMITED', 'FIXED')),
    );
    $form['pspp_get_data']['type_txt']['pspp_get_data_firstcase'] = array(
      '#type' => 'textfield',
      '#title' => t('FIRSTCASE'),
      '#default_value' => $this->options['pspp_get_data_firstcase'],
      '#size' => 2,
    );
    $form['pspp_get_data']['type_txt']['pspp_get_data_importcase'] = array(
      '#type' => 'select',
      '#title' => t('IMPORTCASE'),
      '#default_value' => $this->options['pspp_get_data_importcase'],
      '#options' => array('ALL' => 'ALL', 'FIRST' => 'FIRST "n" cases', 'PERCENT' => 'PERCENT "%"'),
    );
    $form['pspp_get_data']['type_txt']['pspp_get_data_importcase_value'] = array(
      '#type' => 'textfield',
      '#title' => t('IMPORTCASE value (only for FIRST and PERCENT)'),
      '#default_value' => $this->options['pspp_get_data_importcase_value'],
      '#size' => 3,
    );
    $form['pspp_get_data']['type_txt']['pspp_get_data_delimiters'] = array(
      '#type' => 'textfield',
      '#title' => t('DELIMITERS'),
      '#default_value' => $this->options['pspp_get_data_delimiters'],
      '#size' => 3,
    );
    $form['pspp_get_data']['type_txt']['pspp_get_data_qualifier'] = array(
      '#type' => 'textfield',
      '#title' => t('QUALIFIER'),
      '#default_value' => $this->options['pspp_get_data_qualifier'],
      '#size' => 3,
    );
    $form['pspp_get_data']['type_txt']['pspp_get_data_escape'] = array(
      '#type' => 'checkbox',
      '#title' => t('ESCAPE'),
      '#default_value' => $this->options['pspp_get_data_escape'],
    );
    $form['pspp_get_data']['type_txt']['pspp_get_data_delcase'] = array(
      '#type' => 'select',
      '#title' => t('DELCASE'),
      '#default_value' => $this->options['pspp_get_data_delcase'],
      '#options' => array('LINE' => 'LINE', 'VARIABLES' => 'VARIABLES "n" variables'),
    );
    $form['pspp_get_data']['type_txt']['pspp_get_data_delcase_value'] = array(
      '#type' => 'textfield',
      '#title' => t('DELCASE value (only for VARIABLES)'),
      '#default_value' => $this->options['pspp_get_data_delcase_value'],
      '#size' => 3,
    );
  }

  function validate() {
    $errors = parent::validate();

    $linked_id = FALSE;
    if (isset($this->display->display_options['link_display'])) {
      $linked_id = $this->display->display_options['link_display'];
    }
    elseif (isset($this->view->display['default']->display_options['link_display'])) {
      $linked_id = $this->view->display['default']->display_options['link_display'];
    }

    $linked = & $this->view->display[$linked_id];
    if ($linked->display_options['style_plugin'] != 'views_pspp_csv') {
      $errors[] = t('Display "%display" is a PSPP Syntax style and must be linked to a PSPP CSV display style. Use the "Link display" setting to link to the proper PSPP CSV display.', array('%display' => $this->display->display_title));
    }
    else {
      if (empty($linked->display_options['style_options']['filename'])) {
        $errors[] = t('Display %display is linked to a PSPP CSV display %linked that has no filename defined. PSPP Syntax need the filename of the data file to be referred. Enter %linked display, edit the style settings and enter a filename under "Provide as file" option.', array('%display' => $this->display->display_title, '%linked' => $linked->display_title));
      }
    }

    return $errors;
  }
}
